<?php


namespace Repositories;


use Doctrine\ORM\EntityManager;
use Util\InstanceProvider;
use Teknisa\Model\Traits\TQuery;

class Notice
{
    use TQuery;
    /**
     * @var EntityManager
     */
    private $entityManager;

    /**
     * Notice constructor.
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    // TO_CHAR(SYSDATE, 'DD/MM/YYYY')

    public function getNoticeRecords()
    {
        $query = <<<SQL
        SELECT INF.NRINFECOMMERCE,
               INF.DSTITULOINF,
               INF.TXCONTEUDOINF,
               INF.IDNOTIFICACAO,
               TO_CHAR(INF.DTINFORMARIVI, 'DD/MM/YYYY') AS DTINFORMARIVI,
               TO_CHAR(INF.DTEXPIRAINFO, 'DD/MM/YYYY') AS DTEXPIRAINFO,
               TO_CHAR(INF.DTINCLUSAO, 'DD/MM/YYYY') AS DTINCLUSAO,
               TO_CHAR(INF.DTULTATU, 'DD/MM/YYYY') AS DTULTATU,
               INF.IDATIVO,
               INF.CDPUBLICOALVO
          FROM INFORMATIVOECOMMERCE INF
SQL;

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query);
    }

    public function insertNotice($data)
    {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        try {
            $query = <<<SQL
            INSERT
              INTO INFORMATIVOECOMMERCE
                   (NRINFECOMMERCE,
                   DSTITULOINF,
                   TXCONTEUDOINF,
                   IDNOTIFICACAO,
                   DTINFORMARIVI,
                   DTEXPIRAINFO,
                   DTINCLUSAO,
                   DTULTATU,
                   IDATIVO,
                   CDPUBLICOALVO)
            VALUES (:ID,
                   :TITULO,
                   :CONTEUDO,
                   :TIPO,
                   TRUNC(CAST(:DATAINICIO AS DATE)),
                   TRUNC(CAST(:DATATERMINO AS DATE)),
                   TRUNC(CAST(SYSDATE AS DATE)),
                   TRUNC(CAST(SYSDATE AS DATE)),
                   :ATIVO,
                   :CDPUBLICOALVO)
SQL;
            $params = array(
                'ID' => $data['id'],
                'TITULO' => $data['title'],
                'CONTEUDO' => $data['contentText'],
                'TIPO' => $data['type'],
                'DATAINICIO' => $data['dateBegin'],
                'DATATERMINO' => $data['dateEnd'],
                'ATIVO' => $data['active'],
                'CDPUBLICOALVO' => $data['publicoAlvoNotice']
            );

            $connection->executeQuery($query, $params);
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw new \Exception($e->getMessage());
        }
    }

    public function deleteNotice($ids)
    {

        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        try {
            foreach ($ids as $id) {
                $query = <<<SQL
                DELETE
                  FROM INFORMATIVOECOMOPER
                 WHERE NRINFECOMMERCE = ?
SQL;
                $connection->executeQuery($query, array($id));

                $query = <<<SQL
                DELETE
                  FROM INFORMATIVOECOMMERCE
                 WHERE NRINFECOMMERCE = ?
SQL;
                $connection->executeQuery($query, array($id));
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw new \Exception($e->getMessage());
        }
    }

    public function updateNotice($data)
    {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        try {
            foreach ($data as $item) {
                $query = <<<SQL
                 UPDATE INFORMATIVOECOMMERCE 
                    SET DSTITULOINF = :TITULO, 
                        TXCONTEUDOINF = :CONTEUDO, 
                        IDNOTIFICACAO = :TIPO, 
                        DTINFORMARIVI = TRUNC(CAST(:DATAINICIO AS DATE)),
                        DTEXPIRAINFO = TRUNC(CAST(:DATATERMINO AS DATE)), 
                        DTULTATU = TRUNC(CAST(SYSDATE AS DATE)),
                        IDATIVO = :ATIVO,
                        CDPUBLICOALVO = :CDPUBLICOALVO
                  WHERE NRINFECOMMERCE = :ID
SQL;
                $params = array(
                    'ID' => $item['id'],
                    'TITULO' => $item['title'],
                    'CONTEUDO' => $item['content'],
                    'TIPO' => $item['type'],
                    'DATAINICIO' => $item['dateBegin'],
                    'DATATERMINO' => $item['dateEnd'],
                    'ATIVO' => $item['active'],
                    'CDPUBLICOALVO' => $item['publicoAlvoNoticeEdit']
                );
                $connection->executeQuery($query, $params);
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw new \Exception($e->getMessage());
        }
    }

    public function getTimeOutnotice()
    {
        $query = <<<SQL
        SELECT ID,
               NAME,
               QTDIAS,
               IDATIVO
          FROM TIME_OUT_NOTICE
SQL;
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query);
    }

    public function saveTimeOutNotice($connection, $id, $name, $qtDias, $cdoperador, $nrorg) {
        $query = <<<SQL
        INSERT INTO TIME_OUT_NOTICE
               (ID, NAME, QTDIAS, IDATIVO, NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
        VALUES (:ID, :NAME, :QTDIAS, 'S', :NRORG, SYSDATE, :NRORGINCLUSAO, :CDOPERINCLUSAO)
SQL;
        $params = array(
            'ID' => $id,
            'NAME' => $name,
            'QTDIAS' => $qtDias,
            'NRORG' => $nrorg,
            'NRORGINCLUSAO' => $nrorg,
            'CDOPERINCLUSAO' => $cdoperador
        );

        $connection->executeStatement($query, $params);
    }

    public function updateTimeOutNotice($connection, $id, $name, $qtDias, $cdoperador, $nrorg) {
        $query = <<<SQL
        UPDATE TIME_OUT_NOTICE
            SET NAME = :NAME,
                QTDIAS = :QTDIAS,
                IDATIVO = 'S',
                NRORG = :NRORG,
                DTULTATU = SYSDATE,
                NRORGULTATU = :NRORGULTATU,
                CDOPERULTATU = :CDOPERULTATU
        WHERE ID = :ID
SQL;
        $params = array(
            'ID' => $id,
            'NAME' => $name,
            'QTDIAS' => $qtDias,
            'NRORG' => $nrorg,
            'NRORGULTATU' => $nrorg,
            'CDOPERULTATU' => $cdoperador
        );

        $connection->executeStatement($query, $params);
    }

    public function deleteTimeOutNotice($connection, $id) {
        $query = <<<SQL
            DELETE FROM TIME_OUT_NOTICE
            WHERE ID = :ID
SQL;
        $params = array(
            'ID' => $id
        );

        $connection->executeQuery($query, $params);
    }

    public function validaRegistroIgual($connection, $id, $name)
    {
        $query = <<<SQL
        SELECT COUNT(*) AS QTD
        FROM TIME_OUT_NOTICE
        WHERE NAME = :NAME
        AND ID != :ID
SQL;

        $params = array(
            'ID' => $id,
            'NAME' => $name
        );

        return $connection->executeQuery($query, $params)->fetchAllAssociative();
    }
}
