import { Form, Modal, ModalService, DialogService } from '@zeedhi/common';
import { Metadata } from '@zeedhi/core';
import { RichText } from '@zeedhi/zd-richtext-common';

export class PreViewNoticeForOperatorController {
    private modalNotificationList!: Modal;

    public getTextAnuncio: string = '';

    public visibleIframe: boolean = false;

    public visibleText: boolean = false;

    public visibleImage: boolean = false;

    public getValueLink: string = '';

    public getTextContent: string = '';

    public async createdModalPreView() {
        this.modalNotificationList = await ModalService.createFromJson('pages/noticeForOperator/preViewNoticeModal', true);
    }

    public async setIFrameDocSource(itemUrl: string) {
        if (itemUrl) {
            const doomIframes: HTMLIFrameElement[] = Array.from(document.querySelectorAll('#preView_iframeDoc'));
            doomIframes.forEach((element: HTMLIFrameElement) => {
                element.src = `${itemUrl}#zoom=76`;
            });
        }
    }

    public async closeNotificationsModal() {
        this.modalNotificationList.hide();
        this.visibleIframe = false;
        this.visibleText = false;
        this.visibleImage = false;
    }

    public async openNotificationsPre({ component }: any) {
        let form: any;
        if (component.name === 'preView-notice-button') {
            form = Metadata.getInstance<Form>('add-modal-form');
        }
        if (component.name === 'preViewEdit-notice-button') {
            form = Metadata.getInstance<Form>('view-modal-form');
        }
        const valueForm = form.value;
        const richText = Metadata.getInstance<RichText>('rich-text');
        const contentText = richText.content;
        if (valueForm.link || contentText) {
            this.modalNotificationList.show();
            setTimeout(() => {
                this.openNotifications(valueForm, contentText);
            }, 100);
        } else {
            DialogService.show(
                {
                    name: 'nocontent_preView-dialog',
                    type: 'error',
                    title: 'Comunicado sem conteúdo',
                    text: 'O comunicado deve ter um link ou conteúdo para ser visualizado',
                },
            );
        }
    }

    public async openNotifications(valueForm: any, contentText: any) {
        this.getTextAnuncio = valueForm.title;
        if (valueForm.type === 'P') {
            this.visibleIframe = true;
            this.visibleText = false;
            this.visibleImage = false;
            this.setIFrameDocSource(valueForm.link);
        } else if (valueForm.type === 'I') {
            this.visibleIframe = false;
            this.visibleText = false;
            this.visibleImage = true;
            this.getValueLink = valueForm.link;
        } else if (valueForm.type === 'H') {
            this.visibleIframe = false;
            this.visibleText = true;
            this.visibleImage = false;
            this.getTextContent = contentText;
        }
    }
}
